@@ -4,9 +4,6 @@ THEME_BLUEPRINT_NAME = "theme"
 
 THEME_URL_PREFIX = "/theme"
 
-THEME_CONFIG_DEBUG = False
-"""Print the theme default configurations at startup"""
-
 BASE_TEMPLATE = "layouts/page.html"
 """The base template that all templates should extend. Defaults to 'layouts/page.html"""
 
